The nowcast_eval() function returns an object of this class.
Arguments
- detail
data.frame. Per-prediction errors with columns for observed value, predicted value, last reported value.
- summary
data.frame. Aggregated metrics per group x delay: SMAPE (pred and obs), SMAPE improvement, proportion_pred_is_better, Wilson CIs.
- params
list. Parameters used for the evaluation run.
- n_past
integer. Number of past reporting periods evaluated.
- time_start
POSIXct. Time the function started.
- time_end
POSIXct. Time the function ended.
Value
An S7 object of class nowcast_eval_results with the following slots:
- detail
Data frame. Per-prediction errors with columns for observed value, predicted value, last reported value.
- summary
Data frame. Aggregated metrics per group x delay: SMAPE (pred and obs), SMAPE improvement, proportion_pred_is_better, Wilson CIs.
- params
List. Parameters used for the evaluation run.
- n_past
Numeric. Number of past reporting periods evaluated.
- time_start
POSIXct. Time the function started.
- time_end
POSIXct. Time the function ended.